﻿$(document).ready(function () {
    /* Hide the shopping cart on the side since there is a similar one displayed on this page. */
    $('.shopping-cart-container').hide();

    // Populate the dropdown with all of the states.
    for (var i = 0; i < states.length; i++)
    {
        $('.checkout-state').append($('<option>').text(states[i].name).attr('data-abbr', states[i].abbr));
    }

    // Populate the dropdowns with the carriers.
    for (var i = 0; i < carriers.length; i++) {
        var option = $('<option>').text(carriers[i].name);
        option.attr('data-id', carriers[i].id);
        option.data('carrierPlans', carriers[i].carrierPlans);
        $('.checkout-carriers').append(option);
    }

    //Populate the dropdown with the existing addresses
    for (var i = 0; i < existingAddresses.length; i++)
    {
        var addr = existingAddresses[i];
        var option = $('<option>').text(addr.address + " " + addr.city + ", " + addr.state).attr('data-id', addr.id);
        $('.checkout-addresses').append(option);
    }

    // If the user selects an existing address, disable the other fields.
    $('.checkout-addresses').change(function ()
    {
        if(parseInt($('.checkout-addresses option:selected').attr('data-id')) >= 0)
        {
            $('.checkout-address').prop('disabled', true);
            $('.checkout-city').prop('disabled', true);
            $('.checkout-state').prop('disabled', true);
            $('.checkout-apt').prop('disabled', true);
        } else {
            $('.checkout-address').prop('disabled', false);
            $('.checkout-city').prop('disabled', false);
            $('.checkout-state').prop('disabled', false);
            $('.checkout-apt').prop('disabled', false);
        }
    })

    //If the carrier changes, update the carrier plans and the cart total.
    $('.checkout-carriers').change(function () {
        $('.checkout-plans').empty();
        var optionSelected = $("option:selected", this);
        for (var i = 0; i < optionSelected.data('carrierPlans').length; i++) {
            var currentPlan = optionSelected.data('carrierPlans')[i];
            var name = currentPlan.name + " ($" + currentPlan.cost.toFixed(2) + ")";
            $('.checkout-plans').append($('<option>').text(name).attr('data-id', currentPlan.id).attr('data-cost', currentPlan.cost));
        }
        updateCheckoutCart();
    });

    // Populate the default carrier plans
    for(var i = 0; i < carriers[0].carrierPlans.length; i++)
    {
        var currentPlan = carriers[0].carrierPlans[i];
        var name = currentPlan.name + " ($" + currentPlan.cost.toFixed(2) + ")";
        $('.checkout-plans').append($('<option>').text(name).attr('data-id', currentPlan.id).attr('data-cost', currentPlan.cost));
    }

    // Update the cart when the carrier plans change
    $('.checkout-plans').change(function()
    {
        updateCheckoutCart();
    })

    // Initalize the cart
    updateCheckoutCart();

    $('.submit-order').click(function () {
        submitOrder();
    });
});

// Update all of the items in the cart by creating the html for each book and calculating the total cost.
function updateCheckoutCart() {
    $('.cart-items').empty();

    var total = 0;
    total += parseFloat($('.checkout-plans option:selected').attr('data-cost'));
    $('.cart-shipping-cost').text("$" + parseFloat(total).toFixed(2));

    var stringData = $.cookie("cartData");

    if (stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    for (var i = 0; i < data.length; i++) {
        var itemTotal = parseFloat(data[i].cost) * parseFloat(data[i].quantity);
        total += itemTotal;

        var item = $('<div>').addClass('cart-item');
        item.append($('<img>').addClass('cart-item-module').prop('src', "/Content/images/books/" + data[i].ID + ".jpg").prop('height', 60));
   
        var titleElem = $('<div>').addClass('cart-item-module').append($('<a>').prop('href', "/Website/Book/" + data[i].ID).append($('<h4>').text(data[i].name)));
        item.append(titleElem);

        var remove = $('<div>').addClass('cart-item-module pull-right')
        .append($('<h4>').append($('<i>').addClass('glyphicon glyphicon-remove text-danger')));
        item.append(remove);

        var id = data[i].ID;
        var title = data[i].name;
        var cost = data[i].cost;
        var quantity = data[i].quantity;
        remove.click(function () {
            console.log("Removing");
            $(this).closest('.cart-item').remove();
            addOrUpdateBookToCart(id, title, 0, cost);
            updateCheckoutCart();
        });

        var itemCost= $('<div>').addClass('cart-item-module pull-right')
        .append($('<h4>').addClass("cart-item-price").text("$"+itemTotal.toFixed(2)));
        item.append(itemCost);

        var quantityInput = $('<input>').addClass('form-control cart-quantity text-center').prop("value", data[i].quantity);

        var itemQuantity = $('<div>').addClass('cart-item-module pull-right').text("Quantity: ")
        .append(quantityInput);
        item.append(itemQuantity);

        quantityInput.change(function () {
            addOrUpdateBookToCart(id, title, parseInt($(this).val()), cost);
            updateCheckoutCart()
        });

        $('.cart-items').append(item);
    }

    $('.cart-total-cost').text("$" + parseFloat(total).toFixed(2));
}

// Collect the data and submit the order via AJAX
function submitOrder() {
    if ($('.checkout-addresses option:selected').attr('data-id') == -1)
    {
        if ($('.checkout-address').val() == "" || $('.checkout-city').val() == "") {
            alert('You must enter an address.');
            return false;
        }
    }

    $('.submit-order').prop('disabled', true);
    var order = {};

    var stringData = $.cookie("cartData");

    if (stringData == undefined)
        data = [];
    else
        data = $.parseJSON(stringData);

    order.items = data;
    order.carrierService = $('.checkout-plans option:selected').attr('data-id');
    order.existingAddress = $('.checkout-addresses option:selected').attr('data-id');
    order.address = $('.checkout-address').val();
    order.city = $('.checkout-city').val();
    order.apt = $('.checkout-apt').val();
    order.state = $('.checkout-state option:selected').attr('data-abbr');

    $.ajax({
        type: "GET",
        url: "../Website/SubmitOrder",
        data: { data: JSON.stringify(order) },

        success: function (data) {
            for (var i = 0; i < 10; i++)
                clearCart();
            document.location.href = "/Website/OrderView/"+data;
        },
        failure: function (data) {

        }
    })
}